死亡诗社 (豆瓣)
Description: 死亡诗社电影简介和剧情介绍,死亡诗社影评、图片、预告片、影讯、论坛、在线购票
Keywords: 死亡诗社,Dead Poets Society,死亡诗社影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.56豆瓣电影Top250

# 死亡诗社 Dead Poets Society (1989)

导演: 彼得·威尔
编剧: 汤姆·舒尔曼
主演: 罗宾·威廉姆斯 / 罗伯特·肖恩·莱纳德 / 伊桑·霍克 / 乔西·查尔斯 / 盖尔·汉森 / 迪伦·库斯曼 / 阿勒隆·鲁杰罗 / 詹姆斯·沃特斯顿 / 诺曼·劳埃德 / 柯特伍德·史密斯 / 卡拉·贝尔韦尔 / 利昂·波纳尔 / 乔治·马丁 / 乔·奥菲耶里 / 马特·凯里 / 凯文·库尼 / 拉腊·弗林·鲍尔 / 亚历桑德拉·鲍尔斯 / 梅洛拉·沃尔特斯 / 帕梅拉·伯勒尔 / 约翰·库宁汉姆 / 迪布拉·穆尼 / 库尔特·莱特纳 / 凯瑟·斯内德 / 霍纳斯·斯蒂克洛瑞斯 / 杰米·肯尼迪
类型: 剧情
制片国家/地区: 美国
语言: 英语 / 拉丁语
上映日期: 1989-06-02(多伦多首映) / 1989-06-09(美国)
片长: 128 分钟
又名: 暴雨骄阳(港) / 春风化雨(台) / 壮志骄阳
IMDb: tt0097165
豆瓣评分
引用
9.2
676046人评价
5星
64.9%
4星
28.5%
3星
5.9%
2星
0.5%
1星
0.2%
好于 99% 剧情片
想看 看过
评价:
推荐

## 死亡诗社的剧情简介 · · · · · ·

威尔顿预备学院以其沉稳凝重的教学风格和较高的升学率闻名，作为其毕业班的学生，理想就是升入名校。新学期文学老师约翰·基汀（罗宾·威廉姆斯 饰）的到来如同一阵春风，一反传统名校的严肃刻板。
基汀带学生们在校史楼内聆听死亡的声音，反思生的意义 ；让男生们在绿茵场上宣读自己的理想；鼓励学生站在课桌上，用新的视角俯瞰世界。老师自由发散式的哲学思维让学生内心产生强烈的共鸣，他们渐渐学会自己思考与求索，勇敢的追问人生的路途，甚至违反门禁，成立死亡诗社，在山洞里击节而歌！
基汀教授、基汀老师、基汀队长，他的教育宛若春风化雨，润物无声的留在每个人心里… ©豆瓣

## 死亡诗社的演职员 · · · · · · ( 全部 34 )

- 彼得·威尔 导演
- 罗宾·威廉姆斯 饰 John Keating
- 罗伯特·肖恩·莱纳德 饰 Neil Perry
- 伊桑·霍克 饰 Todd Anderson
- 乔西·查尔斯 饰 Knox Overstreet
- 盖尔·汉森 饰 Charlie Dalton

## 死亡诗社的视频和图片 · · · · · · ( 预告片1 | 添加视频评论 | 图片946 · 添加 )

## 死亡诗社的获奖情况 · · · · · · ( 全部 )

- 第62届奥斯卡金像奖
- 最佳影片(提名)
- 保罗·乔恩格·威特 / 托尼·托马斯 / 史蒂文·哈夫特

- 第62届奥斯卡金像奖
- 最佳导演(提名)
- 彼得·威尔

- 第62届奥斯卡金像奖
- 最佳男主角(提名)
- 罗宾·威廉姆斯

## 喜欢这部电影的人也喜欢 · · · · · ·

  心灵捕手

  肖申克的救赎

  阿甘正传

  当幸福来敲门

  国王的演讲

  百万美元宝贝

  贫民窟的百万富翁

  三傻大闹宝莱坞

  摔跤吧！爸爸

  叫我第一名

我要写短评

## 死亡诗社的短评 · · · · · · ( 全部 160801 条 )

热门 / 最新 / 好友

### 9968 有用 传奇☂ 看过 2007-02-27 10:39:27

看这部电影才知道，原来自己已经死去了好久，从某个不经意间被打破的清晨开始。

### 6155 有用 胡如隐 看过 2016-05-01 22:09:33

“金融，工程，建筑，计算，固然很重要，那是我们生存的条件；但诗歌，浪漫，爱，是我们生而为人的原因。”

### 7907 有用 有心打扰 看过 2012-01-04 03:51:33

开场精彩，中场尽显疲态，结局来了个绝杀，最后终于反败为胜，深入我心。凶手毋庸置疑是那个“船长”，他教会了学生追求快乐，但是却没有教会他们反抗，他教学生成为一个理想主义的诗人，却没有教会他们现实的残酷。充满理想的开篇却以悲剧性的事件结尾，理想终归要回到现实，并一直被现实压制。

### 3635 有用 私享史 看过 2008-01-01 11:15:24

《死亡诗社》最后安德森爬上课桌那一幕哭得我稀里哗啦的，一个刚到口的龙眼就活生生地吞下去了。它和《孩子王》有一个同样的情境设定，但立意确实不同的。《孩子王》里“从前有座山”那段也是让我唏嘘呀。另外，《死亡诗社》的中文配音配得很好，不知道出自哪儿。

### 6007 有用 珍妮的肖像🦄 看过 2008-09-07 08:55:48

哦！船长！我的船长！

> 更多短评 160801条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 死亡诗社的影评 · · · · · · ( 全部 4701 条 )

热门 / 最新 / 好友
南桥 2009-08-01 14:52:49

## 这个世界是异类的

这篇影评可能有剧透

有一同事说《死亡诗社》是他有生以来看过的最好的十部影片之一。这是一很好的片子，但人各有好，我更喜欢柯恩兄弟或姜文拍的那种，带些梦幻色彩，带些悬念的影片。比如柯恩的那部《哥们你在哪里？》（又译《逃狱三王》）我就连看了两遍，非常喜欢。《死亡诗社》是一个古老的、... (展开)
7098 356 680回应 收起
woodyallen 2006-12-24 01:56:00

## 死亡诗社里的一段话，四首诗

写在诗社”宝书”的扉页上的那段话来自美国作家THOREAU(1818-1862)的《瓦尔登湖》. 1845年,28岁的THOREAU在好友EMERSON的林地里的WALDEN湖畔盖了座木屋住下,此后两年多里他过着清心寡欲,自给自足的生活,并时常记下自己的所思所想所悟,于是就有了这样一本书. 中文版里徐迟的本... (展开)
5084 115 183回应 收起
秋之萤 2010-06-27 16:12:33

## 《死亡诗社》经典台词欣赏（转）

一、及时行乐，让你的生命超越凡俗 　　《船长，我的船长》Oh ,captain ,my captain! 　　《劝少年们珍惜时光》及时采撷你的花蕾／旧时光一去不回/今天尚在微笑的花朵／明天变得风中枯萎(丁尼生) Gather ye rosebuds while ye may/Old time is still a-flying/And this same ... (展开)
3525 55 67回应 收起
che 2006-05-25 14:22:43

## 《死亡诗社》：这一刻，我开始懂得自己

原本想从网上直接拷贝一些文章来推荐这部电影给大家，但后面想想还是自己写点什么，当是我对于这部电影和导演的敬意。  《死亡诗社》（dead poets society）   有人说我们是缺少信仰、理想和激情的迷茫的一代。从小学、中学到大学关心的只是一味地读好书、作个大... (展开)
2505 179 166回应 收起
tt 2007-12-10 01:32:26

## 作为一个大学毕业生的有感而发

看到底下的评论当中，有些人从老师的立场上讲，认为老师并不应该传道，我觉得难以理解，totaly反对。 教育是老师的教育还是对学生的教育？我想教育是为了学生，所以学生在此问题上应该更有发言权，尤其是经历了中国的流水线式的教育体制之后的学生。 教育应该是怎样的？ 我想... (展开)
1428 120 220回应 收起
feiyafei 2005-06-10 12:24:32

## 这个时候，我想起了Dead Poets Society

Seize the day，make your lives extraordinary ——Dead Poets Society 前几天高考刚刚结束，看看整个社会对其关注程度，说疯狂（insane）都不为过。看着那些所谓的高考语文作文题，几乎都是那么高高在上，要求可怜的饱受摧残学子讨论远离生活的“人生”，不禁深深对那些可怜... (展开)
465 50 122回应 收起
苏凌然 2011-02-05 15:25:19

## 哦，船长，我的船长，我能不能像人一样活着？

有人在影评里说，你们谁的人生被老师改变过。我没有，但我知道，有些人的人生，被Keating老师改变了。我呢，大概也被改变过吧，在高三那个与真正的理想格格不入的时间里，我的语文老师站在讲台上说着《宽容》，说着卡夫卡。他偶尔看着桌子下面几乎所有人都在做着数学习题。其... (展开)
632 12 50回应 收起
十一月的雨 2006-10-05 10:36:35

## 【我最喜欢的十大外语片】之首【死亡诗社】(dead poet society)

青春的祭奠—死亡诗社 文：十一月的雨 在它之前我从来没有想过,会有这么一部影片,影响我的一生。 青春，激情，理想，现实，光影交错中散射的气息竟然与我而今的心情如此的契合。那种迷惘，那种追寻，那种急切的想掘出活着的意义却无毫无头绪的焦躁。王朔在他的小说中形容这种心... (展开)
475 9 43回应 收起

> 更多影评 4701篇

添加新讨论

## 讨论区 · · · · · ·

为啥有那么多人不理解尼尔的自杀 | 来自ellie | 52 回应 | 2022-11-23 02:45:08
关于爱情 | 来自豆友NkSI9SSKmA | 2 回应 | 2022-11-23 02:35:19
可能鸡汤喝多了的人看啥都鸡汤。烂片看多了的人，... | 来自懒人一个。 | 5 回应 | 2022-11-23 02:31:02
想组一个网络“死亡诗社”不知有没有朋友 | 来自鱼 | 43 回应 | 2022-11-23 02:10:45
尼尔的自杀小题大做 | 来自Marioncanal | 120 回应 | 2022-11-21 23:11:01

> 去这部影片的讨论区（全部489条）

## 关于《死亡诗社》的问题 · · · · · · ( 全部24个 )

- 不明白感情线的目的？ 5人回答
- 为什么《死亡诗社》中尼克宁愿自杀都不对父亲说出自己正真想做的事？ 12人回答

> 全部24个问题

## 在哪儿看这部电影 · · · · · ·

- 腾讯视频 免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【内牛满面】 (影志)
- 北京电影学院硕士要看的100部电影 (悲`馨)
- 【励志电影】 (影志)
- 那些牛叉闪闪的片子 (家庭种菜笔记)

## 谁在看这部电影 · · · · · ·

- pp
  3分钟前 想看
- 再见白丝
  4分钟前 想看
- Tonarino ToToRo
  4分钟前 想看

1007229人看过 / 447456人想看

订阅死亡诗社的评论:
feed: rss 2.0